import { LitElement, css, html } from 'lit'
import { customElement, property } from 'lit/decorators.js'

/**
 * An example element.
 *
 * @slot - This element has a slot
 * @csspart button - The button
 */
@customElement('mockup-svg')
export class MockupSvg extends LitElement {
  static styles = css`
    :host {
      width: 100%;
    }
    svg {
      width: 100%;
      max-height: 80vh;
    }
  `;

  @property()
  title = 'Example Alt Text'

  @property()
  description = 'Example Alt Description'

  @property({ type: Number })
  width = 900

  @property({ type: Number })
  height = 1600

  render() {
    return html`
      <p>sup</p>
      <svg viewBox="0 0 ${this.height} ${this.width}" preserveAspectRatio="xMidYMid slice" role="img" aria-labelledby="svgTitle svgDescription">
        <title id="svgTitle">${this.title}</title>
        <desc id="svgDescription">${this.description}</desc>
        <defs>
          <linearGradient id="Gradient-1"
               x1="0" y1="0" x2="100%" y2="0">
              <stop offset="0%" stop-color="lightblue" />
              <stop offset="100%" stop-color="#ef5b2b" />
          </linearGradient>
        </defs>
        <rect x="0" y="0" width="100%" height="100%" fill= "url(#Gradient-1)" />
      </svg>
    `
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'mockup-svg': MockupSvg
  }
}
